:mod:`traits` Module
====================

.. automodule:: traits.traits
    :no-members:

.. currentmodule:: traits.traits

Classes
-------

.. autoclass:: CTrait

.. autoclass:: TraitFactory

.. autoclass:: TraitImportError

.. autoclass:: Default

.. autoclass:: Property

.. autoclass:: ForwardProperty

.. autoclass:: Color

.. autoclass:: RGBColor

.. autoclass:: Font

Functions
---------

.. autofunction:: Trait

.. autofunction:: password_editor

.. autofunction:: multi_line_text_editor

.. autofunction:: code_editor

.. autofunction:: shell_editor

.. autofunction:: time_editor

.. autofunction:: date_editor

.. autofunction:: trait_factory

.. autofunction:: trait_cast

.. autofunction:: try_trait_cast

.. autofunction:: trait_from


Private Classes
---------------

.. autoclass:: traits.traits._InstanceArgs

.. autoclass:: traits.traits._TraitMaker
